@@ -3,3 +3,5 @@ TOKEN_KEY = "LAUNCHABLE_TOKEN"
 ORGANIZATION_KEY = "LAUNCHABLE_ORGANIZATION"
 WORKSPACE_KEY = "LAUNCHABLE_WORKSPACE"
 BASE_URL_KEY = "LAUNCHABLE_BASE_URL"
+SKIP_TIMEOUT_RETRY = "LAUNCHABLE_SKIP_TIMEOUT_RETRY"
+COMMIT_TIMEOUT = "LAUNCHABLE_COMMIT_TIMEOUT"
