@@ -24,10 +24,18 @@ class SessionTest(CliTestCase):
     }, clear=True)
     def test_run_session_without_flavor(self):
         result = self.cli("record", "session", "--build", self.build_name)
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
 
-        payload = json.loads(responses.calls[0].request.body.decode())
-        self.assert_json_orderless_equal({"flavors": {}, "isObservation": False, "links": [], "noBuild": False}, payload)
+        payload = json.loads(responses.calls[1].request.body.decode())
+        self.assert_json_orderless_equal({
+            "flavors": {},
+            "isObservation": False,
+            "links": [],
+            "noBuild": False,
+            "lineage": None,
+            "testSuite": None,
+            "timestamp": None,
+        }, payload)
 
     @responses.activate
     @mock.patch.dict(os.environ, {
@@ -36,10 +44,10 @@ class SessionTest(CliTestCase):
     }, clear=True)
     def test_run_session_with_flavor(self):
         result = self.cli("record", "session", "--build", self.build_name,
-                          "--flavor", "key=value", "--flavor", "k", "v", "--flavor", "k e y = v a l u e")
-        self.assertEqual(result.exit_code, 0)
+                          "--flavor", "key=value", "--flavor", "k:v", "--flavor", "k e y = v a l u e")
+        self.assert_success(result)
 
-        payload = json.loads(responses.calls[0].request.body.decode())
+        payload = json.loads(responses.calls[1].request.body.decode())
         self.assert_json_orderless_equal({
             "flavors": {
                 "key": "value",
@@ -49,13 +57,14 @@ class SessionTest(CliTestCase):
             "isObservation": False,
             "links": [],
             "noBuild": False,
+            "lineage": None,
+            "testSuite": None,
+            "timestamp": None,
         }, payload)
 
-        with self.assertRaises(ValueError):
-            result = self.cli("record", "session", "--build", self.build_name, "--flavor", "only-key")
-            self.assertEqual(result.exit_code, 1)
-            self.assertTrue(
-                "Expected key-value like --option kye=value or --option key value." in result.output)
+        result = self.cli("record", "session", "--build", self.build_name, "--flavor", "only-key")
+        self.assert_exit_code(result, 2)
+        self.assertIn("Expected a key-value pair formatted as --option key=value", result.output)
 
     @responses.activate
     @mock.patch.dict(os.environ, {
@@ -64,11 +73,19 @@ class SessionTest(CliTestCase):
     }, clear=True)
     def test_run_session_with_observation(self):
         result = self.cli("record", "session", "--build", self.build_name, "--observation")
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
 
-        payload = json.loads(responses.calls[0].request.body.decode())
+        payload = json.loads(responses.calls[1].request.body.decode())
 
-        self.assert_json_orderless_equal({"flavors": {}, "isObservation": True, "links": [], "noBuild": False}, payload)
+        self.assert_json_orderless_equal({
+            "flavors": {},
+            "isObservation": True,
+            "links": [],
+            "noBuild": False,
+            "lineage": None,
+            "testSuite": None,
+            "timestamp": None,
+        }, payload)
 
     @responses.activate
     @mock.patch.dict(os.environ, {
@@ -78,7 +95,7 @@ class SessionTest(CliTestCase):
     def test_run_session_with_session_name(self):
         # session name is already exist
         result = self.cli("record", "session", "--build", self.build_name, "--session-name", self.session_name)
-        self.assertEqual(result.exit_code, 2)
+        self.assert_exit_code(result, 2)
 
         responses.replace(
             responses.GET,
@@ -93,10 +110,81 @@ class SessionTest(CliTestCase):
         )
         # invalid session name
         result = self.cli("record", "session", "--build", self.build_name, "--session-name", "invalid/name")
-        self.assertEqual(result.exit_code, 2)
+        self.assert_exit_code(result, 2)
 
         result = self.cli("record", "session", "--build", self.build_name, "--session-name", self.session_name)
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
 
-        payload = json.loads(responses.calls[2].request.body.decode())
-        self.assert_json_orderless_equal({"flavors": {}, "isObservation": False, "links": [], "noBuild": False}, payload)
+        payload = json.loads(responses.calls[5].request.body.decode())
+        self.assert_json_orderless_equal({
+            "flavors": {},
+            "isObservation": False,
+            "links": [],
+            "noBuild": False,
+            "lineage": None,
+            "testSuite": None,
+            "timestamp": None,
+        }, payload)
+
+    @responses.activate
+    @mock.patch.dict(os.environ, {
+        "LAUNCHABLE_TOKEN": CliTestCase.launchable_token,
+        'LANG': 'C.UTF-8',
+    }, clear=True)
+    def test_run_session_with_lineage(self):
+        result = self.cli("record", "session", "--build", self.build_name,
+                          "--lineage", "example-lineage")
+        self.assert_success(result)
+
+        payload = json.loads(responses.calls[1].request.body.decode())
+        self.assert_json_orderless_equal({
+            "flavors": {},
+            "isObservation": False,
+            "links": [],
+            "noBuild": False,
+            "lineage": "example-lineage",
+            "testSuite": None,
+            "timestamp": None,
+        }, payload)
+
+    @responses.activate
+    @mock.patch.dict(os.environ, {
+        "LAUNCHABLE_TOKEN": CliTestCase.launchable_token,
+        'LANG': 'C.UTF-8',
+    }, clear=True)
+    def test_run_session_with_test_suite(self):
+        result = self.cli("record", "session", "--build", self.build_name,
+                          "--test-suite", "example-test-suite")
+        self.assert_success(result)
+
+        payload = json.loads(responses.calls[1].request.body.decode())
+        self.assert_json_orderless_equal({
+            "flavors": {},
+            "isObservation": False,
+            "links": [],
+            "noBuild": False,
+            "lineage": None,
+            "testSuite": "example-test-suite",
+            "timestamp": None,
+        }, payload)
+
+    @responses.activate
+    @mock.patch.dict(os.environ, {
+        "LAUNCHABLE_TOKEN": CliTestCase.launchable_token,
+        'LANG': 'C.UTF-8',
+    }, clear=True)
+    def test_run_session_with_timestamp(self):
+        result = self.cli("record", "session", "--build", self.build_name,
+                          "--timestamp", "2023-10-01T12:00:00Z")
+        self.assert_success(result)
+
+        payload = json.loads(responses.calls[1].request.body.decode())
+        self.assert_json_orderless_equal({
+            "flavors": {},
+            "isObservation": False,
+            "links": [],
+            "noBuild": False,
+            "lineage": None,
+            "testSuite": None,
+            "timestamp": "2023-10-01T12:00:00+00:00",
+        }, payload)
