@@ -28,13 +28,8 @@ class TestsTest(CliTestCase):
                           self.session, '--group', 'hoge', 'maven', str(
                               self.report_files_dir) + "**/reports/")
 
-        self.assertEqual(result.exit_code, 0)
-        # get request body
-        # responses.calls[0]: GET: build information
-        # responses.calls[1]: POST: record tests
-        request = json.loads(gzip.decompress(
-            responses.calls[1].request.body).decode())
-
+        self.assert_success(result)
+        request = json.loads(gzip.decompress(self.find_request('/events').request.body).decode())
         self.assertCountEqual(request.get("group", []), "hoge")
 
     @responses.activate
@@ -59,7 +54,7 @@ class TestsTest(CliTestCase):
         self.assertIn(remove_backslash(broken_xml), remove_backslash(result.output))
 
         # normal.xml
-        self.assertIn('open_class_user_test.rb', gzip.decompress(responses.calls[2].request.body).decode())
+        self.assertIn('open_class_user_test.rb', gzip.decompress(self.find_request('/events').request.body).decode())
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -86,7 +81,7 @@ class TestsTest(CliTestCase):
             status=200)
 
         result = self.cli('record', 'tests', '--no-build', 'maven', str(self.report_files_dir) + "**/reports/")
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
 
     def test_parse_launchable_timeformat(self):
         t1 = "2021-04-01T09:35:47.934+00:00"  # 1617269747.934
@@ -100,3 +95,15 @@ class TestsTest(CliTestCase):
         self.assertEqual(parse_launchable_time2.timestamp(), 1621880944.285)
 
         self.assertEqual(INVALID_TIMESTAMP, parse_launchable_timeformat(t3))
+
+    @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
+    def test_when_total_test_duration_zero(self):
+        write_build(self.build_name)
+
+        zero_duration_xml1 = str(Path(__file__).parent.joinpath('../../data/googletest/output_a.xml').resolve())
+        zero_duration_xml2 = str(Path(__file__).parent.joinpath('../../data/googletest/output_b.xml').resolve())
+        result = self.cli('record', 'tests', '--build', self.build_name, 'googletest', zero_duration_xml1, zero_duration_xml2)
+
+        self.assert_success(result)
+        self.assertIn("Total test duration is 0.", result.output)
