@@ -14,7 +14,24 @@ namespace calc
         [Test]
         public void Test2()
         {
-            Assert.Fail();
+            Assert.Fail("test 2 failed");
+        }
+    }
+
+    public class Outer
+    {
+        public class Inner
+        {
+            [Test]
+            public void Test3()
+            {
+                // this is how you access the inner class, but ...
+                var x = new Outer.Inner();
+
+                // you get the different type name
+                Assert.That(typeof(Inner).Name, Is.EqualTo("Inner"));
+                Assert.That(typeof(Inner).FullName, Is.EqualTo("calc.Outer+Inner"));
+            }
         }
     }
 }
