@@ -2,7 +2,6 @@ import gzip
 import itertools
 import json
 import os
-from pathlib import Path
 from unittest import mock
 
 import responses  # type: ignore
@@ -12,7 +11,6 @@ from tests.cli_test_case import CliTestCase
 
 
 class BazelTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath('../data/bazel/').resolve()
     subset_input = """Starting local Bazel server and connecting to it...
 //src/test/java/com/ninjinkun:mylib_test9
 //src/test/java/com/ninjinkun:mylib_test8
@@ -33,12 +31,9 @@ Loading: 2 packages loaded
         write_build(self.build_name)
 
         result = self.cli('subset', '--target', '10%', 'bazel', input=self.subset_input)
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
         self.assertEqual(read_session(self.build_name), self.session)
-
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('subset_result.json'))
-        self.assert_json_orderless_equal(payload, expected)
+        self.assert_subset_payload('subset_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -47,16 +42,9 @@ Loading: 2 packages loaded
         write_build(self.build_name)
 
         result = self.cli('record', 'tests', 'bazel', str(self.test_files_dir) + "/")
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
         self.assertEqual(read_session(self.build_name), self.session)
-
-        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result.json'))
-
-        for c in payload['events']:
-            del c['created_at']
-
-        self.assert_json_orderless_equal(payload, expected)
+        self.assert_record_tests_payload('record_test_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -66,16 +54,9 @@ Loading: 2 packages loaded
 
         result = self.cli('record', 'tests', 'bazel', '--build-event-json', str(
             self.test_files_dir.joinpath("build_event.json")), str(self.test_files_dir) + "/")
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
         self.assertEqual(read_session(self.build_name), self.session)
-
-        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_with_build_event_json_result.json'))
-
-        for c in payload['events']:
-            del c['created_at']
-
-        self.assert_json_orderless_equal(payload, expected)
+        self.assert_record_tests_payload('record_test_with_build_event_json_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -87,17 +68,9 @@ Loading: 2 packages loaded
                           str(self.test_files_dir.joinpath("build_event.json")),
                           '--build-event-json', str(self.test_files_dir.joinpath("build_event_rest.json")),
                           str(self.test_files_dir) + "/")
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
         self.assertEqual(read_session(self.build_name), self.session)
-
-        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath(
-            'record_test_with_multiple_build_event_json_result.json'))
-
-        for c in payload['events']:
-            del c['created_at']
-
-        self.assert_json_orderless_equal(payload, expected)
+        self.assert_record_tests_payload('record_test_with_multiple_build_event_json_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -110,14 +83,14 @@ Loading: 2 packages loaded
         """
         result = self.cli('subset', '--target', '10%', 'bazel', input=self.subset_input)
 
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
 
-        subset_payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
+        subset_payload = json.loads(gzip.decompress(self.find_request('/subset').request.body).decode())
 
         result = self.cli('record', 'tests', 'bazel', str(self.test_files_dir) + "/")
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
 
-        record_payload = json.loads(gzip.decompress(responses.calls[3].request.body).decode())
+        record_payload = json.loads(gzip.decompress(self.find_request('/events').request.body).decode())
 
         record_test_paths = itertools.chain.from_iterable(e['testPath'] for e in record_payload['events'])
         record_test_path_dict = {t['name']: t for t in record_test_paths}
