@@ -1,20 +1,15 @@
 import glob
-import gzip
-import json
 import os
-from pathlib import Path
 from unittest import mock
 
 import responses  # type: ignore
 
-from launchable.test_runners.cucumber import _create_file_candidate_list
+from launchable.test_runners.cucumber import _create_file_candidate_list, clean_uri
 from launchable.utils.session import write_build
 from tests.cli_test_case import CliTestCase
 
 
 class CucumberTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath('../data/cucumber/').resolve()
-
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_test(self):
@@ -27,14 +22,8 @@ class CucumberTest(CliTestCase):
 
         result = self.cli('record', 'tests', '--base', str(self.test_files_dir), 'cucumber', *reports)
 
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
-        for c in payload['events']:
-            del c['created_at']
-
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result.json'))
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_record_tests_payload('record_test_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -48,17 +37,15 @@ class CucumberTest(CliTestCase):
 
         result = self.cli('record', 'tests', 'cucumber', "--json", *reports)
 
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
-
-        for c in payload['events']:
-            del c['created_at']
-
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_json_result.json'))
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_record_tests_payload('record_test_json_result.json')
 
     def test_create_file_candidate_list(self):
         self.assertCountEqual(_create_file_candidate_list("a-b"), ["a/b", "a-b"])
         self.assertCountEqual(_create_file_candidate_list("a-b-c"), ["a/b/c", "a-b/c", "a/b-c", "a-b-c"])
         self.assertCountEqual(_create_file_candidate_list("a_b_c"), ["a_b_c"])
+
+    def test_clean_uri(self):
+        self.assertEqual(clean_uri('foo/bar/baz.feature'), 'foo/bar/baz.feature')
+        self.assertEqual(clean_uri('file:foo/bar/baz.feature'), 'foo/bar/baz.feature')
+        self.assertEqual(clean_uri('classpath:foo/bar/baz.feature'), 'foo/bar/baz.feature')
