@@ -1,8 +1,5 @@
-import gzip
-import json
 import os
 import tempfile
-from pathlib import Path
 from unittest import mock
 
 import responses  # type: ignore
@@ -13,19 +10,14 @@ from tests.cli_test_case import CliTestCase
 
 
 class GoTestTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath('../data/go_test/').resolve()
-
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset_with_session(self):
         pipe = "TestExample1\nTestExample2\nTestExample3\nTestExample4\n" \
                "ok      github.com/launchableinc/rocket-car-gotest      0.268s"
         result = self.cli('subset', '--target', '10%', '--session', self.session, 'go-test', input=pipe)
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[0].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('subset_result.json'))
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_subset_payload('subset_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -37,30 +29,18 @@ class GoTestTest(CliTestCase):
                "ok      github.com/launchableinc/rocket-car-gotest      0.268s"
         result = self.cli('subset', '--target', '10%', 'go-test', input=pipe)
 
-        self.assertEqual(result.exit_code, 0)
-        self.assertEqual(read_session(self.build_name), self.session)
+        self.assert_success(result)
 
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('subset_result.json'))
-        self.assert_json_orderless_equal(expected, payload)
+        self.assertEqual(read_session(self.build_name), self.session)
+        self.assert_subset_payload('subset_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_tests_with_session(self):
         result = self.cli('record', 'tests', '--session',
                           self.session, 'go-test', str(self.test_files_dir.joinpath('reportv1')) + "/")
-        self.assertEqual(result.exit_code, 0)
-
-        self.assertIn('events', responses.calls[1].request.url, 'call events API')
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-        # Remove timestamp because it depends on the machine clock
-        for c in payload['events']:
-            del c['created_at']
-
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result.json'))
-        self.assert_json_orderless_equal(expected, payload)
-
-        self.assertIn('close', responses.calls[3].request.url, 'call close API')
+        self.assert_success(result)
+        self.assert_record_tests_payload('record_test_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -69,37 +49,18 @@ class GoTestTest(CliTestCase):
         write_build(self.build_name)
 
         result = self.cli('record', 'tests', 'go-test', str(self.test_files_dir.joinpath('reportv1')) + "/")
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
 
         self.assertEqual(read_session(self.build_name), self.session)
-
-        self.assertIn('events', responses.calls[2].request.url, 'call events API')
-        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
-        for c in payload['events']:
-            del c['created_at']
-
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result.json'))
-        self.assert_json_orderless_equal(expected, payload)
-
-        self.assertIn('close', responses.calls[4].request.url, 'call close API')
+        self.assert_record_tests_payload('record_test_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_tests_v2(self):
         result = self.cli('record', 'tests', '--session',
                           self.session, 'go-test', str(self.test_files_dir.joinpath('reportv2')) + "/")
-        self.assertEqual(result.exit_code, 0)
-
-        self.assertIn('events', responses.calls[1].request.url, 'call events API')
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-        # Remove timestamp because it depends on the machine clock
-        for c in payload['events']:
-            del c['created_at']
-
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result.json'))
-        self.assert_json_orderless_equal(expected, payload)
-
-        self.assertIn('close', responses.calls[3].request.url, 'call close API')
+        self.assert_success(result)
+        self.assert_record_tests_payload('record_test_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -142,7 +103,8 @@ class GoTestTest(CliTestCase):
             'go-test',
         )
 
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
+
         self.assertEqual("^TestExample1$|^TestExample2$\n", result.output)
         same_bin_file.close()
         os.unlink(same_bin_file.name)
