@@ -1,7 +1,4 @@
-import gzip
-import json
 import os
-from pathlib import Path
 from unittest import mock
 
 import responses  # type: ignore
@@ -10,8 +7,6 @@ from tests.cli_test_case import CliTestCase
 
 
 class GoogleTestTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath('../data/googletest/').resolve()
-
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset(self):
@@ -22,23 +17,16 @@ class GoogleTestTest(CliTestCase):
   Foo
         """
         result = self.cli('subset', '--target', '10%', '--session', self.session, 'googletest', input=pipe)
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[0].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('subset_result.json'))
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_subset_payload('subset_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_test_googletest(self):
         result = self.cli('record', 'tests', '--session', self.session,
                           'googletest', str(self.test_files_dir) + "/")
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result.json'))
-
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_record_tests_payload('record_test_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -46,12 +34,8 @@ class GoogleTestTest(CliTestCase):
         # ./test_a --gtest_output=xml:output.xml
         result = self.cli('record', 'tests', '--session', self.session,
                           'googletest', str(self.test_files_dir) + "/fail/")
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('fail/record_test_result.json'))
-
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_record_tests_payload('fail/record_test_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -60,4 +44,4 @@ class GoogleTestTest(CliTestCase):
         result = self.cli('record', 'tests', '--session', self.session,
                           'googletest', path)
         self.assertEqual(result.output.rstrip('\n'), "No matches found: {}".format(path))
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
