@@ -1,8 +1,6 @@
 import gzip
-import json
 import os
 import tempfile
-from pathlib import Path
 from unittest import mock
 
 import responses  # type: ignore
@@ -14,9 +12,6 @@ from tests.helper import ignore_warnings
 
 
 class GradleTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath('../data/gradle/').resolve()
-    result_file_path = test_files_dir.joinpath('recursion/expected.json')
-
     @ignore_warnings
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -51,7 +46,8 @@ class GradleTest(CliTestCase):
             str(self.test_files_dir.joinpath('java/app/src/test').resolve()))
         # TODO: we need to assert on the request payload to make sure it found
         # test list all right
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
+
         output = "--tests com.launchableinc.rocket_car_gradle.App2Test " \
                  "--tests com.launchableinc.rocket_car_gradle.AppTest " \
                  "--tests com.launchableinc.rocket_car_gradle.sub.App3Test " \
@@ -97,7 +93,8 @@ class GradleTest(CliTestCase):
             'subset', '--target', '10%', '--rest', rest.name, 'gradle',
             str(self.test_files_dir.joinpath('java/app/src/test/java').resolve()))
 
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
+
         self.assertIn("--tests com.launchableinc.rocket_car_gradle.App2Test "
                       "--tests com.launchableinc.rocket_car_gradle.AppTest "
                       "--tests com.launchableinc.rocket_car_gradle.utils.UtilsTest",
@@ -260,7 +257,7 @@ class GradleTest(CliTestCase):
                 0,
                 "Exit code is not 0. The output is\n" + result.output + "\n" + result.stderr)
 
-        body = gzip.decompress(responses.calls[1].request.body).decode('utf8')
+        body = gzip.decompress(self.find_request('/subset').request.body).decode('utf8')
         self.assertNotIn("java.com.launchableinc.rocket_car_gradle.App2Test", body)
 
     @responses.activate
@@ -302,7 +299,8 @@ class GradleTest(CliTestCase):
             'gradle',
             str(self.test_files_dir.joinpath('java/app/src/test/java').resolve()))
 
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
+
         self.assertIn("subset/123", result.output.rstrip('\n'))
 
     @ignore_warnings
@@ -339,7 +337,8 @@ class GradleTest(CliTestCase):
             rest.name,
             'gradle')
 
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
+
         self.assertIn(
             "--tests com.launchableinc.rocket_car_gradle.App2Test "
             "--tests com.launchableinc.rocket_car_gradle.AppTest "
@@ -390,7 +389,8 @@ class GradleTest(CliTestCase):
             'gradle',
         )
 
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
+
         self.assertIn(
             "--tests com.launchableinc.rocket_car_gradle.App2Test "
             "--tests com.launchableinc.rocket_car_gradle.AppTest "
@@ -405,9 +405,5 @@ class GradleTest(CliTestCase):
     def test_record_test_gradle(self):
         result = self.cli('record', 'tests', '--session', self.session,
                           'gradle', str(self.test_files_dir) + "/**/reports")
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-
-        expected = self.load_json_from_file(self.result_file_path)
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_record_tests_payload('recursion/expected.json')
