@@ -1,5 +1,3 @@
-import gzip
-import json
 import os
 from pathlib import Path
 from unittest import mock
@@ -13,7 +11,6 @@ from tests.helper import ignore_warnings
 
 
 class JestTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath('../data/jest/').resolve()
     # This string generate absolute paths because the CLI requires exsisting
     # directory path
     subset_input = """
@@ -40,12 +37,8 @@ class JestTest(CliTestCase):
 
         result = self.cli('subset', '--target', '10%', '--base',
                           os.getcwd(), 'jest', input=self.subset_input)
-        print(result.output)
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('subset_result.json'))
-        self.assert_json_orderless_equal(payload, expected)
+        self.assert_success(result)
+        self.assert_subset_payload('subset_result.json')
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -75,7 +68,8 @@ class JestTest(CliTestCase):
         result = self.cli('subset', '--target', '20%', '--base', os.getcwd(), '--split',
                           'jest', input=self.subset_input)
 
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
+
         self.assertIn('subset/123', result.output)
 
     @responses.activate
@@ -85,8 +79,5 @@ class JestTest(CliTestCase):
         write_build(self.build_name)
 
         result = self.cli('record', 'tests', 'jest', str(self.test_files_dir.joinpath("junit.xml")))
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result.json'))
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_record_tests_payload('record_test_result.json')
