@@ -1,8 +1,5 @@
-import gzip
-import json
 import os
 import tempfile
-from pathlib import Path
 from unittest import mock
 
 import responses  # type: ignore
@@ -13,8 +10,6 @@ from tests.helper import ignore_warnings
 
 
 class NUnitTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath('../data/nunit/').resolve()
-
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset(self):
@@ -81,13 +76,8 @@ class NUnitTest(CliTestCase):
 
         result = self.cli('subset', '--target', '10%', '--session', self.session, 'nunit',
                           str(self.test_files_dir) + "/list.xml")
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[0].request.body).decode())
-
-        expected = self.load_json_from_file(self.test_files_dir.joinpath('subset_result.json'))
-
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_subset_payload('subset_result.json')
 
         output = 'ParameterizedTests.MyTests.DivideTest(12,3)\ncalc.Tests1.Test1'
         self.assertIn(output, result.output)
@@ -150,7 +140,7 @@ class NUnitTest(CliTestCase):
         result = self.cli('split-subset', '--subset-id', 'subset/456',
                           '--bin', '1/2', '--rest', rest.name, 'nunit')
 
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
 
         self.assertIn('ParameterizedTests.MyTests.DivideTest(12,3)', result.output)
 
@@ -164,23 +154,23 @@ class NUnitTest(CliTestCase):
     def test_record_test_on_linux(self):
         result = self.cli('record', 'tests', '--session', self.session,
                           'nunit', str(self.test_files_dir) + "/output-linux.xml")
-        self.assertEqual(result.exit_code, 0)
-
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-
-        expected = self.load_json_from_file(self.test_files_dir.joinpath("record_test_result.json"))
-
-        self.assert_json_orderless_equal(expected, payload)
+        self.assert_success(result)
+        self.assert_record_tests_payload("record_test_result-linux.json")
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_test_on_windows(self):
         result = self.cli('record', 'tests', '--session', self.session,
                           'nunit', str(self.test_files_dir) + "/output-windows.xml")
-        self.assertEqual(result.exit_code, 0)
+        self.assert_success(result)
+        self.assert_record_tests_payload("record_test_result-windows.json")
 
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
-
-        expected = self.load_json_from_file(self.test_files_dir.joinpath("record_test_result.json"))
-
-        self.assert_json_orderless_equal(expected, payload)
+    @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
+    def test_record_test_with_nunit_reporter_bug(self):
+        result = self.cli('record', 'tests', '--session', self.session,
+                          'nunit', str(self.test_files_dir) + "/nunit-reporter-bug-with-nested-type.xml")
+        self.assert_success(result)
+        # turns out we collapse all TestFixtures to TestSuitest so the golden file has TestSuite=Outer+Inner,
+        # not TestFixture=Outer+Inner
+        self.assert_record_tests_payload("nunit-reporter-bug-with-nested-type.json")
